package cn.teammodel.controller.admin.service.impl;

import cn.teammodel.common.ErrorCode;
import cn.teammodel.common.PK;
import cn.teammodel.config.exception.ServiceException;
import cn.teammodel.controller.admin.service.TeacherService;
import cn.teammodel.model.dto.admin.teacher.GpTeacherDto;
import cn.teammodel.model.dto.admin.teacher.TeacherDto;
import cn.teammodel.model.entity.common.GroupList;
import cn.teammodel.model.entity.school.GpTeacher;
import cn.teammodel.model.entity.school.LessonRecord;
import cn.teammodel.model.entity.school.School;
import cn.teammodel.model.entity.school.SchoolTeacher;
import cn.teammodel.model.vo.admin.GpTeacherVo;
import cn.teammodel.model.vo.admin.SugVo;
import cn.teammodel.model.vo.admin.TeacherGradeVo;
import cn.teammodel.repository.LessonRecordRepository;
import cn.teammodel.repository.SchoolGroupListRepository;
import cn.teammodel.repository.SchoolRepository;
import cn.teammodel.repository.SchoolTeacherRepository;
import cn.teammodel.test.LessonRecordQueryService;
import cn.teammodel.utils.GroupUtil;
import cn.teammodel.utils.SchoolDateUtil;
import com.azure.cosmos.CosmosException;
import com.azure.spring.data.cosmos.core.query.CosmosPageRequest;
import org.apache.commons.lang3.ObjectUtils;
import org.apache.commons.lang3.StringUtils;
import org.jetbrains.annotations.NotNull;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.core.env.Environment;
import org.springframework.data.domain.Slice;
import org.springframework.data.domain.SliceImpl;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.time.*;
import java.time.format.DateTimeFormatter;
import java.util.*;
import java.util.concurrent.ExecutionException;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import java.util.stream.Collectors;

import static cn.teammodel.utils.SchoolDateUtil.calculateWeekNum;

@Service
public class TeacherServiceImpl implements TeacherService {
    @Resource
    private SchoolTeacherRepository schoolTeacherRepository;
    @Resource
    private SchoolGroupListRepository schoolGroupListRepository;
    @Resource
    private SchoolRepository  schoolRepository;
    @Resource
    private LessonRecordRepository lessonRecordRepository;
    @Autowired
    private Environment env;

    @Override
    public List<Map<String, Integer>> getTeacherList(TeacherDto teacherDto) {
        List<Map<String, Integer>> result = new ArrayList<>();
        Map<String, Integer> teacherCountMap = new HashMap<>();
        Map<String, Integer> groupCountMap = new HashMap<>();
       List<GroupList> groupLists = schoolGroupListRepository.findAllByCode("GroupList-" + teacherDto.getCode());
       List<SchoolTeacher> schoolTeachers = schoolTeacherRepository.findAllByCode("Teacher-" + teacherDto.getCode());
       teacherCountMap.put("教师总人数", schoolTeachers.size());
       List<School> school = schoolRepository.findBaseById(teacherDto.getCode());
       List<School.Subject> subjects = new ArrayList<>();
       List<School.Period> periods = new ArrayList<>();
       for (School sc : school) {
           if (sc.getPeriod() != null) {
               // 遍历每个 Period 对象
               for (School.Period period : sc.getPeriod()) {
                   periods.add(period);
                   // 检查 period 是否有 subjects 列表
                   if (period.getSubjects() != null) {
                       // 将 period 中的 subjects 添加到总的 subjects 列表中
                       subjects.addAll(period.getSubjects());
                   }
               }
           }

       }

        Map<String, Integer> updatedSubjectCountMap = getStringIntegerMap(subjects, schoolTeachers);

        // 创建一个映射，用于存储每个职位的教师数量
        Map<String, Integer> jobCountMap = new HashMap<>();

        // 遍历所有教师
        for (SchoolTeacher teacher : schoolTeachers) {
            // 获取教师的职位
            String job = teacher.getJob();
            if (job != null) {
                // 更新每个职位的教师数量
                jobCountMap.put(job, jobCountMap.getOrDefault(job, 0) + 1);
            }
        }
        jobCountMap.entrySet().removeIf(entry -> entry.getKey().isEmpty());
        Map<String, Integer> periodCountMap = getPeriodCountMap(periods,schoolTeachers);
        for (GroupList groupList : groupLists) {
            groupCountMap.put(groupList.getName(), groupList.getMembers().size());
        }
        periodCountMap.entrySet().removeIf(entry -> entry.getKey().isEmpty());
        updatedSubjectCountMap.entrySet().removeIf(entry -> entry.getKey().isEmpty());
        result.add(updatedSubjectCountMap);
        result.add(jobCountMap);
        result.add(periodCountMap);
        result.add(teacherCountMap);
        result.add(groupCountMap);
        return result;
    }

    @Override
    public Map<String, Object> getTeacherDetail(TeacherDto teacherDto, HttpServletRequest request) {

        Map<String, Object> teachers;
        //获取全学校教师名单详情
        String url = env.getProperty("ies.server-url-get-teacher-all");
        try {
            teachers =  GroupUtil.getGroupId(teacherDto,new GroupUtil(env), request,url);
            List<GpTeacherVo> teachersList = new ArrayList<>();
            for (Map.Entry<String, Object> entry : teachers.entrySet()) {
                // 假设 entry.getValue() 返回的是 List<Map<String, Object>>
                List<Map<String, Object>> mapList = (List<Map<String, Object>>) entry.getValue();
                for (Map<String, Object> map : mapList) {
                    // 将 Map 转换为 GpTeacherVo 对象
                    GpTeacherVo teacher = convertToGpTeacherVo(map);
                    teachersList.add(teacher);
                }
            }
            List<String> phones = new ArrayList<>();
            // 进一步处理 teachersList
            for (GpTeacherVo teacher : teachersList) {
                phones.add(teacher.getPhone());
            }
            GpTeacherDto gpTeacherDto = new GpTeacherDto();
            gpTeacherDto.setMobiles(phones);
            Map<String, Object> tBase = getTeacherBase(gpTeacherDto, request);
            List<GpTeacher> gpTeachers = new ArrayList<>();
            for (Map.Entry<String, Object> entry : tBase.entrySet()) {
                if (entry.getKey().equals("teachers")) {
                    List<Map<String, Object>> dataList = (List<Map<String, Object>>) entry.getValue();
                    for (Map<String, Object> dataMap : dataList) {
                        GpTeacher gpTeacher = convertToGpTeacher(dataMap);
                        gpTeachers.add(gpTeacher);
                    }
                }
            }
            Map<String, Long> genderCount = gpTeachers.stream()
                    .collect(Collectors.groupingBy(gpTeacher -> gpTeacher.getBasic().getGender(), Collectors.counting()));
            Map<String, Long> degreeCount = gpTeachers.stream()
                    .filter(gpTeacher -> gpTeacher.getDegree() != null)
                    .collect(Collectors.groupingBy(GpTeacher::getDegree, Collectors.counting()));
            //Map<String, Integer> practiceCount = getStringIntegerMap(teacherDto, gpTeachers);

            if(!genderCount.containsKey("F")) {
                genderCount.put("F",0L);
            }else if (!genderCount.containsKey("S")) {
                genderCount.put("S",0L);
            }else if (!genderCount.containsKey("M")){
                genderCount.put("M",0L);
            }
           /* Map<String, Object> genderMap = new HashMap<>();
            Map<String, Object> practiceMap = new HashMap<>();
            for (GpTeacher gpTeacher : gpTeachers) {
                genderMap.put(gpTeacher.basic.name, gpTeacher.basic.gender);
                practiceMap.put(gpTeacher.basic.name, gpTeacher.practiceTime);
            }*/

            for (GpTeacherVo teacher : teachersList) {
                for(GpTeacher gpTeacher : gpTeachers) {
                    if(StringUtils.isNotEmpty(teacher.phone) && teacher.phone.equalsIgnoreCase(gpTeacher.mobile)) {
                        if(gpTeacher.basic.gender != null) {
                            teacher.setGender(gpTeacher.basic.gender);
                        }else {
                            teacher.setGender("");
                        }
                        if (gpTeacher.getPracticeTime() != null && gpTeacher.getPracticeTime() > 0) {
                            teacher.setPracticeTime(gpTeacher.getPracticeTime());
                        }else {
                            teacher.setPracticeTime(0L);
                        }
                        if(gpTeacher.degree != null) {
                            teacher.setDegree(gpTeacher.degree);
                        }else {
                            teacher.setDegree("");
                        }
                        break;
                    }
                }
            }
            //teachers.put("practice", practiceCount);
            //teachers.put("practiceMap", practiceMap);
            //teachers.put("genderMap", genderMap);
            teachers.put("gender", genderCount);
            teachers.put("degree", degreeCount);
            teachers.put("info", teachersList);
            teachers.remove("teachers");

        }catch (Exception e) {
            throw new ServiceException(ErrorCode.SYSTEM_ERROR.getCode(), "数据转换错误");

        }
        return teachers;
    }

    private static @NotNull Map<String, Integer> getStringIntegerMap(TeacherDto teacherDto, List<GpTeacher> gpTeachers) {
        Map<String,Integer> practiceCount = new HashMap<>();
        for (GpTeacher gpTeacher : gpTeachers) {
            if(gpTeacher.practiceTime > 0) {
                // 将时间戳转换为 LocalDateTime
                LocalDateTime dateTime = LocalDateTime.ofInstant(
                        Instant.ofEpochMilli(gpTeacher.practiceTime),
                        ZoneId.systemDefault()
                );

                // 获取年份
                int year = dateTime.getYear();
                practiceCount.put(gpTeacher.basic.name, teacherDto.year - year);
            }
        }
        return practiceCount;
    }

    private GpTeacherVo convertToGpTeacherVo(Map<String, Object> map) {
        GpTeacherVo teacher = new GpTeacherVo();
        // 假设 GpTeacherVo 有以下属性：name, age, subject
        teacher.setName((String) map.get("name"));
        teacher.setPhone((String) map.get("phone"));
        teacher.setId((String) map.get("id"));
        teacher.setEmail((String) map.get("email"));
        teacher.setPicture((String) map.get("picture"));
        teacher.setIname((String) map.get("iname"));
        teacher.setJob((String) map.get("job"));
        teacher.setRoles((List<String>) map.get("roles"));
        //teacher.setGroups((List<GpTeacherVo.IdNameCode>) map.get("groups"));
        List<Map<String, Object>> groupList = (List<Map<String, Object>>) map.get("groups");
        if (groupList != null) {

            List<GpTeacherVo.IdNameCode> groups = new ArrayList<>();
            for (Map<String, Object> groupMap : groupList) {
                GpTeacherVo.IdNameCode group = new GpTeacherVo.IdNameCode();
                group.setId((String) groupMap.get("id"));
                group.setName((String) groupMap.get("name"));
                group.setCode((String) groupMap.get("code"));
                group.setPicture((String) groupMap.get("picture"));
                group.setNickname((String) groupMap.get("nickname"));
                groups.add(group);
            }
            teacher.setGroups(groups);
        }
        //teacher.setDegree((String) map.get("degree"));
        //teacher.setPracticeTime((String) map.get("practiceTime"));
        //teacher.setGender((String) map.get("gender"));
        teacher.setNote((String) map.get("note"));
        teacher.setSubjectIds((List<String>) map.get("subjectIds"));
        teacher.setSubjectNames((List<String>) map.get("subjectNames"));
        // 根据实际属性进行转换
        return teacher;
    }

    private TeacherGradeVo convertToTeacherGradeVo(Map<String, Object> map) {
        TeacherGradeVo teacher = new TeacherGradeVo();
        teacher.setName((String) map.get("name"));
        teacher.setId((String) map.get("tmdId"));
        teacher.setPeriodId((String) map.get("periodId"));
        // 处理 grade 字段
        List<Map<String, Object>> gradeList = (List<Map<String, Object>>) map.get("grade");
        if (gradeList != null) {
            List<TeacherGradeVo.IdAndName> grades = new ArrayList<>();
            for (Map<String, Object> gradeMap : gradeList) {
                TeacherGradeVo.IdAndName grade = new TeacherGradeVo.IdAndName();
                grade.setGrade((Integer) gradeMap.get("grade"));
                grade.setGradeName((String) gradeMap.get("gradeName"));
                grades.add(grade);
            }
            teacher.setGrade(grades);
        }
        // 根据实际属性进行转换
        return teacher;
    }
    private GpTeacher convertToGpTeacher(Map<String, Object> map) {
        GpTeacher teacher = new GpTeacher();
        // 假设 GpTeacherVo 有以下属性：name, age, subject
        Object describeObj = map.get("describe");
        if (describeObj instanceof String) {
            teacher.setDescribe((String) describeObj);
        } else {
            teacher.setDescribe(null); // 或者设置一个默认值
        }
        Object IdObj = map.get("id");
        if (describeObj instanceof String) {
            teacher.setId((String) IdObj);
        } else {
            teacher.setId(null); // 或者设置一个默认值
        }
        Object depictObj = map.get("depict");
        if (depictObj instanceof String) {
            teacher.setDepict((String) depictObj);
        } else {
            teacher.setDepict(null); // 或者设置一个默认值
        }
        teacher.setPeriods((ArrayList<GpTeacher.GnericBase>) map.get("periods"));
        teacher.setSubjects((ArrayList<GpTeacher.GnericBase>) map.get("subjects"));
        teacher.setGrades((ArrayList<GpTeacher.GnericBase>) map.get("grades"));
        Object practiceTimeObj = map.get("practiceTime");
        if (practiceTimeObj instanceof Long) {
            teacher.setPracticeTime((Long) practiceTimeObj);
        } else {
            teacher.setPracticeTime(0L); // 或者设置一个默认值
        }
        Object titleObj = map.get("title");
        if (titleObj instanceof String) {
            teacher.setTitle((String) titleObj);
        } else {
            teacher.setTitle(null); // 或者设置一个默认值
        }
        Object mobileObj = map.get("mobile");
        if (mobileObj instanceof String) {
            teacher.setMobile((String) mobileObj);
        } else {
            teacher.setMobile(null); // 或者设置一个默认值
        }
        Object degreeObj = map.get("degree");
        if (degreeObj instanceof String) {
            teacher.setDegree((String) degreeObj);
        } else {
            teacher.setDegree(null); // 或者设置一个默认值
        }
        Map<String, Object> basicMap = (Map<String, Object>) map.get("basic");
        //teacher.setBasic(new GpTeacher.GPBasicInfo(basicMap.get("name").toString(),basicMap.get("fullName").toString(),basicMap.get("picture").toString(),basicMap.get("region").toString(),basicMap.get("province").toString(),basicMap.get("city").toString(),basicMap.get("dist").toString(),basicMap.get("gender").toString(),basicMap.get("age").toString(),basicMap.get("address").toString()));
        GpTeacher.GPBasicInfo basic = new GpTeacher.GPBasicInfo();
        Object nameObj = basicMap.get("name");
        if (nameObj instanceof String) {
            basic.setName((String) nameObj);
        } else {
            basic.setName(null); // 或者设置一个默认值
        }
        Object fullNameObj = basicMap.get("fullName");
        if (fullNameObj instanceof String) {
            basic.setFullName((String) fullNameObj);
        } else {
            basic.setFullName(null); // 或者设置一个默认值
        }
        Object distObj = basicMap.get("dist");
        if (distObj instanceof String) {
            basic.setDist((String) distObj);
        } else {
            basic.setDist(null); // 或者设置一个默认值
        }
        Object genderObj = basicMap.get("gender");
        if (genderObj instanceof String) {
            basic.setGender((String) genderObj);
        } else {
            basic.setGender(null); // 或者设置一个默认值
        }
        Object ageObj = basicMap.get("age");
        if (ageObj instanceof Integer) {
            basic.setAge((Integer) ageObj);
        } else {
            basic.setAge(0); // 或者设置一个默认值
        }
        teacher.basic = basic;


        // 根据实际属性进行转换
        return teacher;
    }

    @Override
    public Map<Long, Integer> getTeacherByRecord(TeacherDto teacherDto) {
        final int SLICE_SIZE = 10000;
        // 获取学期起止时间
        List<School.Semester> semesters = schoolRepository.findSemestersById(teacherDto.getCode(), teacherDto.getPeriodId());
        SchoolDateUtil.semesterModel semesterModel = SchoolDateUtil.getSemesterByNow(semesters, LocalDate.now());
        LocalDateTime startDatetime;
        LocalDateTime endDatetime;
        if(teacherDto.getStartTime() != null) {
            startDatetime = LocalDateTime.ofInstant(Instant.ofEpochMilli(teacherDto.getStartTime()), ZoneId.systemDefault());
            endDatetime = LocalDateTime.ofInstant(Instant.ofEpochMilli(teacherDto.getEndTime()), ZoneId.systemDefault());
        }else {
            startDatetime = semesterModel.getStartDatetime();
            endDatetime = semesterModel.getEndDatetime();
        }
        if (startDatetime == null || endDatetime == null) throw new ServiceException(ErrorCode.PARAMS_ERROR);
        long totalWeek = calculateWeekNum(startDatetime, endDatetime, null);

        // slice 分段读取
        CosmosPageRequest pageRequest = new CosmosPageRequest(0, SLICE_SIZE, null);
        Slice<LessonRecord> slice;
        Map<Long, Integer> countByWeek = SchoolDateUtil.createEmptyWeekMap(totalWeek);
        String lessonRecordKey = String.format(PK.PK_LESSON_RECORD, teacherDto.getCode());
        do {
            if(StringUtils.isNotEmpty(teacherDto.getGrade())) {
                slice = lessonRecordRepository.findAllByGrade(lessonRecordKey, teacherDto.getGrade(),teacherDto.getSubjectId(),teacherDto.getPeriodId(),pageRequest);
            } else if(StringUtils.isNotEmpty(teacherDto.getTmdId())) {
                slice = lessonRecordRepository.findAllByAcademicYearId(lessonRecordKey, teacherDto.getTmdId(),teacherDto.getSubjectId(),teacherDto.getPeriodId(),pageRequest);
            } else {
                slice = lessonRecordRepository.findAll(lessonRecordKey, teacherDto.getSubjectId(),teacherDto.getPeriodId(), pageRequest);
            }
            List<LessonRecord> content = slice.getContent();
            if (ObjectUtils.isEmpty(content)) {
                break;
            }

            // 分批次计算
            for (LessonRecord item : content) {
                long weekNum = calculateWeekNum(startDatetime, endDatetime, item.getStartTime());
                countByWeek.merge(weekNum, 1, Integer::sum); // 使用 merge 方法简化代码
            }

            if (slice.hasNext()) {
                pageRequest = (CosmosPageRequest) slice.nextPageable();
            }
        } while (slice.hasNext() && !Thread.currentThread().isInterrupted());
        countByWeek.entrySet().removeIf(entry -> entry.getKey() == -1);
        return countByWeek;
    }

    @Override
    public Map<String, Object> getTeacherLearningCategory(TeacherDto teacherDto) {

        Map<String, Object> LearningCategory = new HashMap<>(Collections.emptyMap());
        try {
            // 获取学期起止时间
            List<School.Semester> semesters = schoolRepository.findSemestersById(teacherDto.getCode(), teacherDto.getPeriodId());
            SchoolDateUtil.semesterModel semesterModel = SchoolDateUtil.getSemesterByNow(semesters, LocalDate.now());
            LocalDateTime startDatetime;
            LocalDateTime endDatetime;
            if(teacherDto.getStartTime() != null) {
                startDatetime = LocalDateTime.ofInstant(Instant.ofEpochMilli(teacherDto.getStartTime()), ZoneId.systemDefault());
                endDatetime = LocalDateTime.ofInstant(Instant.ofEpochMilli(teacherDto.getEndTime()), ZoneId.systemDefault());
            }else {
                startDatetime = semesterModel.getStartDatetime();
                endDatetime = semesterModel.getEndDatetime();
            }
            if (startDatetime == null || endDatetime == null) throw new ServiceException(ErrorCode.PARAMS_ERROR);

            // 将 LocalDateTime 转换为 Long 类型的时间戳
            long startTimestamp = startDatetime.toInstant(ZoneOffset.UTC).toEpochMilli();
            long endTimestamp = endDatetime.toInstant(ZoneOffset.UTC).toEpochMilli();
            List<LessonRecord> lessonRecords = new ArrayList<>();
            //List<LessonRecord> lessonRecords = lessonRecordRepository.getLessonsByConditions(String.format(PK.PK_LESSON_RECORD, teacherDto.getCode()), startTimestamp, endTimestamp, teacherDto.getSubjectId(),teacherDto.getTmdId(),teacherDto.getGrade(),teacherDto.getPeriodId());
            int[] counts = {0, 0, 0, 0, 0};
            String[] keys = {"cooperation", "internet", "task", "exam", "diffential"};

            for (LessonRecord record : lessonRecords) {
                if (record.getLearningCategory() != null) {
                    counts[0] += record.getLearningCategory().getCooperation();
                    counts[1] += record.getLearningCategory().getInteraction();
                    counts[2] += record.getLearningCategory().getTask();
                    counts[3] += record.getLearningCategory().getExam();
                    counts[4] += record.getLearningCategory().getDiffential();
                }
            }

            for (int i = 0; i < keys.length; i++) {
                LearningCategory.put(keys[i], counts[i]);
            }
        }catch (Exception e) {
            throw new ServiceException(ErrorCode.SYSTEM_ERROR.getCode(), "数据转换错误");

        }
        return LearningCategory;
    }

    @Override
    public Map<String, Object> getTeacherGradeCount(TeacherDto teacherDto, HttpServletRequest request) {

        Map<String, Object> gradeMap;
        String url = env.getProperty("ies.server-url-get-teacher-grade-count");
        try {
            gradeMap =  GroupUtil.getGroupId(teacherDto,new GroupUtil(env), request,url);
        }catch (Exception e) {
            throw new ServiceException(ErrorCode.SYSTEM_ERROR.getCode(), "数据转换错误");

        }
        return gradeMap;
    }

    @Override
    public List<Map<String,Map<String, Long>>> getDistributionOfTeachers(TeacherDto teacherDto, HttpServletRequest request) {

        List<Map<String,Map<String, Long>>> distributionList = new ArrayList<>();
        Map<String,Map<String, Long>>  gradesMap = new HashMap<>();
        Map<String,Map<String, Long>> degreesMap = new HashMap<>();
        Map<String,Map<String, Long>> subjectsMap= new HashMap<>();
        Map<String,Map<String, Long>> groupsMap = new HashMap<>();
        Map<String, Object> teachers;
        //获取全学校教师名单详情
        String url = env.getProperty("ies.server-url-get-teacher-all");
        try {
            teachers =  GroupUtil.getGroupId(teacherDto,new GroupUtil(env), request,url);
            List<GpTeacherVo> teachersList = new ArrayList<>();
            for (Map.Entry<String, Object> entry : teachers.entrySet()) {
                // 假设 entry.getValue() 返回的是 List<Map<String, Object>>
                List<Map<String, Object>> mapList = (List<Map<String, Object>>) entry.getValue();
                for (Map<String, Object> map : mapList) {
                    // 将 Map 转换为 GpTeacherVo 对象
                    GpTeacherVo teacher = convertToGpTeacherVo(map);
                    teachersList.add(teacher);
                }
            }
            List<String> phones = new ArrayList<>();
            // 进一步处理 teachersList
            for (GpTeacherVo teacher : teachersList) {
                phones.add(teacher.getPhone());
            }
            GpTeacherDto gpTeacherDto = new GpTeacherDto();
            gpTeacherDto.setMobiles(phones);
            Map<String, Object> tBase = getTeacherBase(gpTeacherDto, request);
            List<GpTeacher> gpTeachers = new ArrayList<>();
            for (Map.Entry<String, Object> entry : tBase.entrySet()) {
                if (entry.getKey().equals("teachers")) {
                    List<Map<String, Object>> dataList = (List<Map<String, Object>>) entry.getValue();
                    for (Map<String, Object> dataMap : dataList) {
                        GpTeacher gpTeacher = convertToGpTeacher(dataMap);
                        gpTeachers.add(gpTeacher);
                    }
                }
            }
            //把对应年级的信息进行映射
            List<TeacherGradeVo> gradeList = new ArrayList<>();
            Map<String,Object> gradeInfo =  getTeacherGradeCount(teacherDto, request);
            for (Map.Entry<String, Object> entry : gradeInfo.entrySet()) {
                if (entry.getKey().equals("teacher")) {
                    List<Map<String, Object>> dataList = (List<Map<String, Object>>) entry.getValue();
                    for (Map<String, Object> dataMap : dataList) {
                        TeacherGradeVo teacherGradeVo = convertToTeacherGradeVo(dataMap);
                        gradeList.add(teacherGradeVo);
                    }
                }
            }
            for (GpTeacherVo teacher : teachersList) {
                for(GpTeacher gpTeacher : gpTeachers) {
                    if(StringUtils.isNotEmpty(teacher.phone) && teacher.phone.equalsIgnoreCase(gpTeacher.mobile)) {
                        if(gpTeacher.basic.gender != null) {
                            teacher.setGender(gpTeacher.basic.gender);
                        }else {
                            teacher.setGender("");
                        }
                        if (gpTeacher.getPracticeTime() != null && gpTeacher.getPracticeTime() > 0) {
                            teacher.setPracticeTime(gpTeacher.getPracticeTime());
                        }else {
                            teacher.setPracticeTime(0L);
                        }
                        if(gpTeacher.degree != null) {
                            teacher.setDegree(gpTeacher.degree);
                        }else {
                            teacher.setDegree("");
                        }
                        break;
                    }
                }
                for (TeacherGradeVo grade : gradeList) {
                    if(StringUtils.isNotEmpty(teacher.getId()) && teacher.getId().equals(grade.getId())) {
                        if(StringUtils.isNotEmpty(grade.getPeriodId())) {
                            teacher.setPeriodId(grade.getPeriodId());
                        }
                        List<TeacherGradeVo.IdAndName> grades = grade.getGrade();
                        for (TeacherGradeVo.IdAndName gg : grades) {
                            String id = String.valueOf(teacherDto.year - gg.getGrade());
                            if (teacher.grade == null) {
                                teacher.setGrade(new ArrayList<>());
                            }
                            teacher.grade.add(id);

                        }
                    }
                }
            }

            teachersList = teachersList.stream()
                    .filter(teacher -> teacherDto.periodId.equals(teacher.getPeriodId()))
                    .collect(Collectors.toList());
            Map<String, Long> gradeCount = new HashMap<>();
            Map<String, Long> degreeCount = new HashMap<>();
            Map<String, Long> subjectCount = new HashMap<>();
            Map<String, Long> GroupCount = new HashMap<>();
            if(StringUtils.isNotEmpty(teacherDto.getGrade()) && StringUtils.isNotEmpty(teacherDto.getSubjectId())) {
                for (GpTeacherVo teacher : teachersList) {
                    if(teacher.getGrade() != null &&teacher.getSubjectIds() != null &&teacher.getGrade().contains(teacherDto.getGrade()) && teacher.getSubjectIds().contains(teacherDto.getSubjectId())) {
                        {
                            Long count = gradeCount.getOrDefault(teacherDto.getGrade(), 0L);
                            gradeCount.put(teacherDto.getGrade(), count + 1);
                        }
                        if(StringUtils.isNotEmpty(teacher.getDegree())) {
                            {
                                Long count = degreeCount.getOrDefault(teacher.getDegree(), 0L);
                                degreeCount.put(teacher.getDegree(), count + 1);
                            }
                        }
                        {
                            int index = teacher.subjectIds.indexOf(teacherDto.getSubjectId());
                            String name = "";
                            if (index >= 0) {
                                name = teacher.subjectNames.get(index);
                            }
                            Long count = subjectCount.getOrDefault(name, 0L);
                            subjectCount.put(name, count + 1);
                        }
                        if(teacher.getGroups() != null) {
                            for (GpTeacherVo.IdNameCode group : teacher.getGroups()) {
                                Long count = GroupCount.getOrDefault(group.getName(), 0L);
                                GroupCount.put(group.getName(), count + 1);
                            }
                        }
                    }
                }
            }else if(StringUtils.isEmpty(teacherDto.getGrade()) && StringUtils.isNotEmpty(teacherDto.getSubjectId())) {
                for (GpTeacherVo teacher : teachersList) {
                    if(teacher.getSubjectIds() != null && teacher.getSubjectIds().contains(teacherDto.getSubjectId())) {
                        if(teacher.getGrade() != null) {
                            for (String grade : teacher.getGrade()) {
                                Long count = gradeCount.getOrDefault(grade, 0L);
                                gradeCount.put(grade, count + 1);
                            }
                        }
                        if(StringUtils.isNotEmpty(teacher.getDegree())) {
                            {
                                Long count = degreeCount.getOrDefault(teacher.getDegree(), 0L);
                                degreeCount.put(teacher.getDegree(), count + 1);
                            }
                        }
                        {
                            int index = teacher.subjectIds.indexOf(teacherDto.getSubjectId());
                            String name = "";
                            if (index >= 0) {
                                name = teacher.subjectNames.get(index);
                            }
                            Long count = subjectCount.getOrDefault(name, 0L);
                            subjectCount.put(name, count + 1);
                        }
                        if(teacher.getGroups() != null) {
                            for (GpTeacherVo.IdNameCode group : teacher.getGroups()) {
                                Long count = GroupCount.getOrDefault(group.getName(), 0L);
                                GroupCount.put(group.getName(), count + 1);
                            }
                        }
                    }
                }
                }else if(StringUtils.isNotEmpty(teacherDto.getGrade()) && StringUtils.isEmpty(teacherDto.getSubjectId())) {

                for (GpTeacherVo teacher : teachersList) {
                    if(teacher.getGrade() != null && teacher.getGrade().contains(teacherDto.getGrade())) {
                        {
                            Long count = gradeCount.getOrDefault(teacherDto.getGrade(), 0L);
                            gradeCount.put(teacherDto.getGrade(), count + 1);
                        }
                        if(StringUtils.isNotEmpty(teacher.getDegree())) {
                            {
                                Long count = degreeCount.getOrDefault(teacher.getDegree(), 0L);
                                degreeCount.put(teacher.getDegree(), count + 1);
                            }
                        }
                        if(teacher.getSubjectIds()!= null) {
                            for (String subjectId : teacher.getSubjectIds()) {
                                int index = teacher.subjectIds.indexOf(subjectId);
                                String name = "";
                                if (index >= 0) {
                                    name = teacher.subjectNames.get(index);
                                }
                                Long count = subjectCount.getOrDefault(name, 0L);
                                subjectCount.put(name, count + 1);
                            }
                        }
                        if(teacher.getGroups() != null) {
                            for (GpTeacherVo.IdNameCode group : teacher.getGroups()) {
                                Long count = GroupCount.getOrDefault(group.getName(), 0L);
                                GroupCount.put(group.getName(), count + 1);
                            }
                        }
                    }
                }

            }else {
                for (GpTeacherVo teacher : teachersList) {
                    if(teacher.getGrade() != null) {
                        for (String grade : teacher.getGrade()) {
                            Long count = gradeCount.getOrDefault(grade, 0L);
                            gradeCount.put(grade, count + 1);
                        }
                    }
                        if(StringUtils.isNotEmpty(teacher.getDegree())) {
                            {
                                Long count = degreeCount.getOrDefault(teacher.getDegree(), 0L);
                                degreeCount.put(teacher.getDegree(), count + 1);
                            }
                        }
                        if(teacher.getSubjectIds()!= null) {
                            for (String subjectId : teacher.getSubjectIds()) {
                                int index = teacher.subjectIds.indexOf(subjectId);
                                String name = "";
                                if (index >= 0) {
                                    name = teacher.subjectNames.get(index);
                                }
                                Long count = subjectCount.getOrDefault(name, 0L);
                                subjectCount.put(name, count + 1);
                            }
                        }
                        if(teacher.getGroups() != null) {
                            for (GpTeacherVo.IdNameCode group : teacher.getGroups()) {
                                Long count = GroupCount.getOrDefault(group.getName(), 0L);
                                GroupCount.put(group.getName(), count + 1);
                            }
                        }

                }
            }
            gradeCount.keySet().removeIf(key -> key.startsWith("20"));
            gradesMap.put("grade", gradeCount);
            degreesMap.put("degree", degreeCount);
            subjectsMap.put("subject", subjectCount);
            groupsMap.put("group", GroupCount);
            distributionList.add(gradesMap);
            distributionList.add(degreesMap);
            distributionList.add(subjectsMap);
            distributionList.add(groupsMap);

           /* Map<String, Long> genderCount = gpTeachers.stream()
                    .collect(Collectors.groupingBy(gpTeacher -> gpTeacher.getBasic().getGender(), Collectors.counting()));
            Map<String, Long> degreeCount = gpTeachers.stream()
                    .filter(gpTeacher -> gpTeacher.getDegree() != null)
                    .collect(Collectors.groupingBy(GpTeacher::getDegree, Collectors.counting()));*/




        }catch (Exception e) {
            throw new ServiceException(ErrorCode.SYSTEM_ERROR.getCode(), "数据转换错误");

        }
        return distributionList;
    }

    @Override
    public Map<String, Object> getTeachingAndResearch(TeacherDto teacherDto, HttpServletRequest request) {
        final int SLICE_SIZE = 1000;
        List<SugVo> sugVoList = getSugVos(teacherDto, request);
        //获取教师年级分配情况
        Map<String, Object> Map = getTeacherGradeCount(teacherDto, request);
        List<TeacherGradeVo> gradeList = new ArrayList<>();
        for (Map.Entry<String, Object> entry : Map.entrySet()) {
            if(entry.getKey().equals("teacher")) {
                List<Map<String, Object>> teacherList = (List<Map<String, Object>>) entry.getValue();
                for (Map<String, Object> statisticsMap : teacherList) {
                    TeacherGradeVo teacherGradeVo = convertToTeacherGradeVo(statisticsMap);
                    gradeList.add(teacherGradeVo);
                }
            }
        }
        List<LessonRecord> records;
        LessonRecordQueryService queryService = new LessonRecordQueryService(lessonRecordRepository);

        try {
            String lessonRecordKey = String.format(PK.PK_LESSON_RECORD, teacherDto.getCode());
            Long startTime = teacherDto.getStartTime();
            Long endTime = teacherDto.getEndTime();
            String subjectId = teacherDto.getSubjectId();
            String tmdId = teacherDto.getTmdId();
            String grade = teacherDto.getGrade();
            String periodId = teacherDto.getPeriodId();

            records = queryService.queryLessonsInParallel(
                    lessonRecordKey, startTime, endTime, subjectId, tmdId, grade, periodId
            );

            System.out.println("查询到的记录数量: " + records.size());
        } catch (InterruptedException | ExecutionException e) {
            throw new ServiceException(ErrorCode.SYSTEM_ERROR.getCode(), "数据查询异常");
        } finally {
            queryService.shutdown();
        }

        //List<LessonRecord> lessonRecords = lessonRecordRepository.getLessonsByConditions(String.format(PK.PK_LESSON_RECORD, teacherDto.getCode()), teacherDto.getStartTime(), teacherDto.getEndTime(), teacherDto.getSubjectId(),teacherDto.getTmdId(),teacherDto.getGrade(),teacherDto.getPeriodId());
        if(teacherDto.getTmdId() != null) {

            List<SugVo> sugVos =  sugVoList.stream().filter(sugVo -> sugVo.getHabook().equals(teacherDto.getTmdId())).collect(Collectors.toList());
            LinkedHashMap<String,Object> mapTeach = new LinkedHashMap<>();
            int[] scores = new int[10];
            for (SugVo sugVo : sugVos) {
                scores[0] += sugVo.getT_data();
                scores[1] += sugVo.getT_green();
                scores[2] += sugVo.getT_duration();
                scores[3] += sugVo.getT_attendance();
                scores[4] += sugVo.getT_interaction();
                scores[5] += sugVo.getLesson_count();
                scores[6] += sugVo.getPublic_count();
                scores[7] += sugVo.getDouble_green_count();
                scores[8] += sugVo.getMaterial_count();
                scores[9] += sugVo.getTpcplan_count();

            }
            //T(数据)
            mapTeach.put("TData",scores[0]);
            //T（绿灯）
            mapTeach.put("TGreen",scores[1]);
            //总时长
            mapTeach.put("TDuration",scores[2]);
            //T(数据)学生人次
            mapTeach.put("TAttendance",scores[3]);
            //T(数据)互动次数
            mapTeach.put("TInteraction",scores[4]);

            mapTeach.put("LessonCount",scores[5]);
            mapTeach.put("PublicCount",scores[6]);
            mapTeach.put("DoubleGreenCount",scores[7]);
            mapTeach.put("MaterialCount",scores[8]);
            mapTeach.put("TpcplanCount",scores[9]);
            mapTeach.put("Lessons",records.size());
            // 检查 sugVos 是否为空
            if (!sugVos.isEmpty()) {
                mapTeach.put("starLevel", sugVos.get(0).getStar_level());
            } else {
                // 处理空列表的情况，例如设置默认值
                mapTeach.put("starLevel", 0); // 或者其他默认值
            }
            return mapTeach;

        }else if(teacherDto.getGradeName() != null) {

            List<String> teachers = new ArrayList<>();
            for (TeacherGradeVo gradeVo : gradeList) {
                for(TeacherGradeVo.IdAndName gradeId : gradeVo.getGrade()) {
                    if (gradeId.getGradeName().equals(teacherDto.getGradeName() )) {
                        teachers.add(gradeVo.getId());
                    }
                }
            }
            List<SugVo> filteredSugVoList = sugVoList.stream()
                    .filter(sugVo -> teachers.contains(sugVo.getHabook()))
                    .collect(Collectors.toList());
            LinkedHashMap<String,Object> mapTeach = new LinkedHashMap<>();
            int[] scores = new int[10];
            for (SugVo sugVo : filteredSugVoList) {
                scores[0] += sugVo.getT_data();
                scores[1] += sugVo.getT_green();
                scores[2] += sugVo.getT_duration();
                scores[3] += sugVo.getT_attendance();
                scores[4] += sugVo.getT_interaction();
                scores[5] += sugVo.getLesson_count();
                scores[6] += sugVo.getPublic_count();
                scores[7] += sugVo.getDouble_green_count();
                scores[8] += sugVo.getMaterial_count();
                scores[9] += sugVo.getTpcplan_count();
            }
            //T(数据)
            mapTeach.put("TData",scores[0]);
            //T（绿灯）
            mapTeach.put("TGreen",scores[1]);
            //总时长
            mapTeach.put("TDuration",scores[2]);
            //T(数据)学生人次
            mapTeach.put("TAttendance",scores[3]);
            //T(数据)互动次数
            mapTeach.put("TInteraction",scores[4]);
            mapTeach.put("LessonCount",scores[5]);
            mapTeach.put("PublicCount",scores[6]);
            mapTeach.put("DoubleGreenCount",scores[7]);
            mapTeach.put("MaterialCount",scores[8]);
            mapTeach.put("TpcplanCount",scores[9]);
            mapTeach.put("Lessons",records.size());

            return mapTeach;
        }else {
            LinkedHashMap<String, Object> mapTeach = new LinkedHashMap<>();
            int[] scores = new int[10];
            for (SugVo sugVo : sugVoList) {
                scores[0] += sugVo.getT_data();
                scores[1] += sugVo.getT_green();
                scores[2] += sugVo.getT_duration();
                scores[3] += sugVo.getT_attendance();
                scores[4] += sugVo.getT_interaction();
                scores[5] += sugVo.getLesson_count();
                scores[6] += sugVo.getPublic_count();
                scores[7] += sugVo.getDouble_green_count();
                scores[8] += sugVo.getMaterial_count();
                scores[9] += sugVo.getTpcplan_count();
            }
            //T(数据)
            mapTeach.put("TData", scores[0]);
            //T（绿灯）
            mapTeach.put("TGreen", scores[1]);
            //总时长
            mapTeach.put("TDuration", scores[2]);
            //T(数据)学生人次
            mapTeach.put("TAttendance", scores[3]);
            //T(数据)互动次数
            mapTeach.put("TInteraction", scores[4]);
            mapTeach.put("LessonCount",scores[5]);
            mapTeach.put("PublicCount",scores[6]);
            mapTeach.put("DoubleGreenCount",scores[7]);
            mapTeach.put("MaterialCount",scores[8]);
            mapTeach.put("TpcplanCount",scores[9]);
            mapTeach.put("Lessons",records.size());

            return mapTeach;

        }

        //Map<String, Object> map = new HashMap<>();
        /*//录课数
        map.put("Lessons",new Random().nextInt(100) + 1);
        //T(数据)
        map.put("TData",new Random().nextInt(100) + 1);
        //T（绿灯）
        map.put("TGreen",new Random().nextInt(100) + 1);
        //双绿灯
        map.put("DoubleGreen",new Random().nextInt(100) + 1);
        //观课数
        map.put("WLessons",new Random().nextInt(100) + 1);
        //议课数
        map.put("TLessons",new Random().nextInt(100) + 1);
        //频道数
        map.put("Channels",new Random().nextInt(20) + 1);
        //公开课
        map.put("OLessons",new Random().nextInt(100) + 1);
        //课件数
        map.put("Coursewares",new Random().nextInt(100) + 1);
        //教案数
        map.put("TeachingPlan",new Random().nextInt(40) + 1);
        //公开标记
        map.put("OMarkers",new Random().nextInt(30) + 1);
        //个人标记
        map.put("PMarkers",new Random().nextInt(30) + 1);
        //被标记数
        map.put("TMarkers",new Random().nextInt(30) + 1);
        //被点阅数
        map.put("ClickAndRead",new Random().nextInt(100) + 1);*/
        //return map;
    }

    @Override
    public List<LinkedHashMap<String,LinkedHashMap<String,Object>>> getTeachingOfTeacher(TeacherDto teacherDto, HttpServletRequest request) {
        List<LinkedHashMap<String,LinkedHashMap<String,Object>>> list = new ArrayList<>();
        List<SugVo> sugVoList = getSugVos(teacherDto, request);
        //获取教师年级分配情况
        Map<String, Object> Map = getTeacherGradeCount(teacherDto, request);
        List<TeacherGradeVo> gradeList = new ArrayList<>();
        for (Map.Entry<String, Object> entry : Map.entrySet()) {
            if(entry.getKey().equals("teacher")) {
                List<Map<String, Object>> teacherList = (List<Map<String, Object>>) entry.getValue();
                for (Map<String, Object> statisticsMap : teacherList) {
                   TeacherGradeVo teacherGradeVo = convertToTeacherGradeVo(statisticsMap);
                    gradeList.add(teacherGradeVo);
                }
            }
        }
        if(teacherDto.getTmdId() != null) {
            List<SugVo> sugVos =  sugVoList.stream().filter(sugVo -> sugVo.getHabook().equals(teacherDto.getTmdId())).collect(Collectors.toList());
            LinkedHashMap<String,Object> mapTeach = new LinkedHashMap<>();
            LinkedHashMap<String,LinkedHashMap<String,Object>> map = new LinkedHashMap<>();
            int[] scores = new int[7];
            for (SugVo sugVo : sugVos) {
                scores[0] += sugVo.getCooperation();
                scores[1] += sugVo.getInteraction();
                scores[2] += sugVo.getTask();
                scores[3] += sugVo.getExam();
                scores[4] += sugVo.getDiffential();
                scores[5] += sugVo.getSmartRating();
                scores[6] += sugVo.getCowork();
            }

            mapTeach.put("cooperation", scores[0]);
            mapTeach.put("interaction", scores[1]);
            mapTeach.put("task", scores[2]);
            mapTeach.put("exam", scores[3]);
            mapTeach.put("differential", scores[4]);
            mapTeach.put("smartRating", scores[5]);
            mapTeach.put("cowork", scores[6]);
            map.put(teacherDto.getTmdId(), mapTeach);
            list.add(map);
        }else {

            List<School> school = schoolRepository.findBaseById(teacherDto.getCode());
            List<String> grades = getGrades(teacherDto, school);
            LinkedHashMap<String,LinkedHashMap<String,Object>> map = new LinkedHashMap<>();
            for (String grade : grades) {
                List<String> teachers = new ArrayList<>();
                for (TeacherGradeVo gradeVo : gradeList) {
                    for(TeacherGradeVo.IdAndName gradeId : gradeVo.getGrade()) {
                        if (gradeId.getGradeName().equals(grade)) {
                            teachers.add(gradeVo.getId());
                        }
                    }
                }
                List<SugVo> filteredSugVoList = sugVoList.stream()
                        .filter(sugVo -> teachers.contains(sugVo.getHabook()))
                        .collect(Collectors.toList());
                LinkedHashMap<String,Object> mapTeach = new LinkedHashMap<>();
                int[] scores = new int[7]; // 索引 0: cooperation, 1: interaction, 2: task, 3: exam, 4: diffential, 5: smartRating, 6: cowork
                for (SugVo sugVo : filteredSugVoList) {
                    scores[0] += sugVo.getCooperation();
                    scores[1] += sugVo.getInteraction();
                    scores[2] += sugVo.getTask();
                    scores[3] += sugVo.getExam();
                    scores[4] += sugVo.getDiffential();
                    scores[5] += sugVo.getSmartRating();
                    scores[6] += sugVo.getCowork();
                }

                mapTeach.put("cooperation", scores[0]);
                mapTeach.put("interaction", scores[1]);
                mapTeach.put("task", scores[2]);
                mapTeach.put("exam", scores[3]);
                mapTeach.put("differential", scores[4]);
                mapTeach.put("smartRating", scores[5]);
                mapTeach.put("cowork", scores[6]);

                map.put(grade, mapTeach);
            }
            list.add(map);
        }

        return list;
    }

    private @NotNull List<SugVo> getSugVos(TeacherDto teacherDto, HttpServletRequest request) {
        String url = env.getProperty("ies.server-url-get-channel-data");
        Map<String, Object> overView;
        List<SugVo> sugVoList = new ArrayList<SugVo>();
        try {
            Instant instantSTime = Instant.ofEpochMilli(teacherDto.getStartTime());
            Instant instantETime = Instant.ofEpochMilli(teacherDto.getEndTime());
            ZoneId zoneId = ZoneId.of("Asia/Shanghai");
            LocalDate localDateSTime = instantSTime.atZone(zoneId).toLocalDate();
            LocalDate localDateETime = instantETime.atZone(zoneId).toLocalDate();
            DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy-MM-dd");
            String sTime = localDateSTime.format(formatter);
            String eTime = localDateETime.format(formatter);
            teacherDto.duration.add(sTime);
            teacherDto.duration.add(eTime);
            teacherDto.school_shortcode.add(teacherDto.getCode());
            overView =  GroupUtil.getGroupId(teacherDto,new GroupUtil(env), request,url);
            for(Map.Entry<String, Object> entry : overView.entrySet()) {
                if (entry.getKey().equals("data")) {
                    List<Map<String, Object>> dataList = (List<Map<String, Object>>) entry.getValue();
                    for (Map<String, Object> dataMap : dataList) {
                        if(dataMap.containsKey("statistics")) {
                            List<Map<String, Object>> statisticsList = (List<Map<String, Object>>) dataMap.get("statistics");
                            for (Map<String, Object> statisticsMap : statisticsList) {
                                SugVo sugVo = convertToSugVo(statisticsMap);
                                sugVoList.add(sugVo);
                            }
                        }
                        if (dataMap.containsKey("member_list")) {
                            List<Map<String, Object>> memberList = (List<Map<String, Object>>) dataMap.get("member_list");
                            for (Map<String, Object> memberMap : memberList) {
                               for (SugVo sugVo : sugVoList) {
                                   if (memberMap.get("habook").equals(sugVo.getHabook())) {
                                       sugVo.setStar_level(Integer.parseInt(memberMap.get("star_level").toString()));
                                   }
                               }
                            }
                        }

                    }
                }
            }
        }catch (Exception e) {
            throw new ServiceException(ErrorCode.SYSTEM_ERROR.getCode(), "数据转换错误");

        }
        return sugVoList;
    }

    private SugVo convertToSugVo(Map<String, Object> dataMap) {
        SugVo sugVo = new SugVo();
        sugVo.setDate(dataMap.get("date").toString());
        sugVo.setHabook(dataMap.get("habook").toString());
        sugVo.setT_data(Integer.parseInt(dataMap.get("t_data").toString()));
        sugVo.setT_green(Integer.parseInt(dataMap.get("t_green").toString()));
        sugVo.setT_duration(Integer.parseInt(dataMap.get("t_duration").toString()));
        sugVo.setT_attendance(Integer.parseInt(dataMap.get("t_attendance").toString()));
        sugVo.setT_interaction(Integer.parseInt(dataMap.get("t_interaction").toString()));
        sugVo.setCooperation(Integer.parseInt(dataMap.get("cooperation").toString()));
        sugVo.setInteraction(Integer.parseInt(dataMap.get("interaction").toString()));
        sugVo.setTask(Integer.parseInt(dataMap.get("task").toString()));
        sugVo.setExam(Integer.parseInt(dataMap.get("exam").toString()));
        sugVo.setDiffential(Integer.parseInt(dataMap.get("diffential").toString()));
        sugVo.setSmartRating(Integer.parseInt(dataMap.get("smartRating").toString()));
        sugVo.setCowork(Integer.parseInt(dataMap.get("cowork").toString()));
        sugVo.setLesson_count(Integer.parseInt(dataMap.get("lesson_count").toString()));
        sugVo.setPublic_count(Integer.parseInt(dataMap.get("public_count").toString()));
        sugVo.setDouble_green_count(Integer.parseInt(dataMap.get("double_green_count").toString()));
        sugVo.setMaterial_count(Integer.parseInt(dataMap.get("material_count").toString()));
        sugVo.setTpcplan_count(Integer.parseInt(dataMap.get("tpcplan_count").toString()));
        return sugVo;
    }

    private static @NotNull List<String> getGrades(TeacherDto teacherDto, List<School> school) {
        List<String> grades = new ArrayList<>();
        if(school != null && !school.isEmpty()) {
            for (School base : school) {
               for (School.Period period : base.getPeriod()) {
                   if(period.getId().equals(teacherDto.getPeriodId())) {
                       for(String grade : period.getGrades()) {
                           grades.add(grade.trim());
                       }
                   }
               }
            }
        }
        return grades;
    }

    public Map<String, Object> getTeacherBase(GpTeacherDto gpTeacherDto, HttpServletRequest request) {

        Map<String, Object> gradeMap;
        try {
            gradeMap =  GroupUtil.getTeacherInfo(gpTeacherDto,new GroupUtil(env), request);
        }catch (Exception e) {
            throw new ServiceException(ErrorCode.SYSTEM_ERROR.getCode(), "国培数据转换错误");

        }
        return gradeMap;
    }

    private static @NotNull Map<String, Integer> getStringIntegerMap(List<School.Subject> subjects, List<SchoolTeacher> schoolTeachers) {
        Map<String, String> subjectNameMap = new HashMap<>();
        for (School.Subject subject : subjects) {
            subjectNameMap.put(subject.getId(), subject.getName());
        }
        Map<String, Integer> subjectCountMap = new HashMap<>();

        // 遍历所有教师
        for (SchoolTeacher teacher : schoolTeachers) {
            // 获取教师的科目列表
            List<String> subjectIds = teacher.getSubjectIds();
            if (subjectIds != null) {
                for (String subjectId : subjectIds) {
                    // 更新每个科目的教师数量
                    subjectCountMap.put(subjectId, subjectCountMap.getOrDefault(subjectId, 0) + 1);
                }
            }
        }
        Map<String, Integer> updatedSubjectCountMap = new HashMap<>();
        for (Map.Entry<String, Integer> entry : subjectCountMap.entrySet()) {
            String subjectId = entry.getKey();
            Integer count = entry.getValue();
            String subjectName = subjectNameMap.get(subjectId);
            if (subjectName != null) {
                updatedSubjectCountMap.put(subjectName, count);
            }
        }
        return updatedSubjectCountMap;
    }

    private static @NotNull Map<String, Integer> getPeriodCountMap(List<School.Period> periods,List<SchoolTeacher> schoolTeachers) {

        Map<String, Integer> periodCountMap = new HashMap<>();
        for (School.Period period : periods) {
            for ( School.Subject subject : period.getSubjects()) {
                for (SchoolTeacher schoolTeacher : schoolTeachers) {
                    if (schoolTeacher.getSubjectIds().contains(subject.getId())) {
                        periodCountMap.put(period.getId(), periodCountMap.getOrDefault(period.getId(), 0) + 1);
                    }
                }
            }
        }
        Map<String, String> periodNameMap = new HashMap<>();
        List<String> periodNames = new ArrayList<>();
        for (School.Period period : periods) {
            periodNameMap.put(period.getId(), period.getName());
            periodNames.add(period.getName());
        }
        //Map<String, Integer> periodCountMap = getStringIntegerMap(groupLists);
        // 更新 periodCountMap 的 key 为 period 名称
        Map<String, Integer> updatedPeriodCountMap = new HashMap<>();
        for (Map.Entry<String, Integer> entry : periodCountMap.entrySet()) {
            String periodId = entry.getKey();
            Integer count = entry.getValue();
            String periodName = periodNameMap.get(periodId);
            if (periodName != null) {
                updatedPeriodCountMap.put(periodName, count);
            }
        }
        for (String periodName : periodNames) {
            if(!updatedPeriodCountMap.containsKey(periodName)) {
                updatedPeriodCountMap.put(periodName, 0);
            }
        }
        return updatedPeriodCountMap;
    }

    /*private static @NotNull Map<String, Integer> getStringIntegerMap(List<GroupList> groupLists) {
        Map<String, Integer> periodCountMap = new HashMap<>();
        // 遍历所有 GroupList 对象
        for (GroupList group : groupLists) {
            // 获取 periodId
            String periodId = group.getPeriodId();
            if (periodId != null) {
                    // 计算成员数量
                    int memberCount = (int) group.getMembers().stream().filter(member -> member.type == 1).count();
                    // 更新 periodCountMap
                    periodCountMap.put(periodId, periodCountMap.getOrDefault(periodId, 0) + memberCount);

            }
        }
        return periodCountMap;
    }*/
}
